@@ -64,19 +64,16 @@ function create_masakari_accounts {
 
         create_service_user "$USERNAME" "admin"
 
-        local masakari_service=$(get_or_create_service "masakari" \
+        local masakari_service
+        masakari_service=$(get_or_create_service "masakari" \
             "instance-ha" "OpenStack High Availability")
         if [ "$MASAKARI_USE_MOD_WSGI" == "False" ]; then
             get_or_create_endpoint $masakari_service \
                 "$REGION_NAME" \
-                "$MASAKARI_SERVICE_PROTOCOL://$SERVICE_HOST:$MASAKARI_SERVICE_PORT/v1/\$(tenant_id)s" \
-                "$MASAKARI_SERVICE_PROTOCOL://$SERVICE_HOST:$MASAKARI_SERVICE_PORT/v1/\$(tenant_id)s" \
                 "$MASAKARI_SERVICE_PROTOCOL://$SERVICE_HOST:$MASAKARI_SERVICE_PORT/v1/\$(tenant_id)s"
         else
             get_or_create_endpoint $masakari_service \
                 "$REGION_NAME" \
-                "$MASAKARI_SERVICE_PROTOCOL://$SERVICE_HOST/instance-ha/v1/\$(tenant_id)s" \
-                "$MASAKARI_SERVICE_PROTOCOL://$SERVICE_HOST/instance-ha/v1/\$(tenant_id)s" \
                 "$MASAKARI_SERVICE_PROTOCOL://$SERVICE_HOST/instance-ha/v1/\$(tenant_id)s"
         fi
     fi
@@ -133,9 +130,9 @@ function configure_masakari {
     # (Re)create masakari api conf file if needed
     if is_service_enabled masakari-api; then
         oslo-config-generator --namespace keystonemiddleware.auth_token \
-                          --namespace masakari \
-                          --namespace oslo.db \
-                          > $MASAKARI_CONF
+            --namespace masakari \
+            --namespace oslo.db \
+            > $MASAKARI_CONF
 
         # Set common configuration values (but only if they're defined)
         iniset $MASAKARI_CONF DEFAULT masakari_api_workers "$API_WORKERS"
@@ -179,9 +176,9 @@ function configure_masakarimonitors {
 
     # (Re)create masakarimonitors api conf file if needed
     oslo-config-generator --namespace masakarimonitors.conf \
-                      --namespace oslo.log \
-                      --namespace oslo.middleware \
-                      > $MASAKARI_MONITORS_CONF
+        --namespace oslo.log \
+        --namespace oslo.middleware \
+        > $MASAKARI_MONITORS_CONF
 
     iniset $MASAKARI_MONITORS_CONF api auth_url "${KEYSTONE_AUTH_PROTOCOL}://${KEYSTONE_AUTH_HOST}/identity"
     iniset $MASAKARI_MONITORS_CONF api password "$SERVICE_PASSWORD"
@@ -194,13 +191,7 @@ function configure_masakarimonitors {
     iniset $MASAKARI_MONITORS_CONF process process_list_path "/etc/masakarimonitors/process_list.yaml"
 
     cp $DEST/masakari-monitors/etc/masakarimonitors/process_list.yaml.sample \
-       $DEST/masakari-monitors/etc/masakarimonitors/process_list.yaml
-    cp $DEST/masakari-monitors/etc/masakarimonitors/process_list.yaml \
-       $MASAKARI_MONITORS_CONF_DIR
-
-    cp $DEST/masakari-monitors/etc/masakarimonitors/processmonitor.conf.sample \
-       $DEST/masakari-monitors/etc/masakarimonitors/processmonitor.conf
-    cp $DEST/masakari-monitors/etc/masakarimonitors/processmonitor.conf $MASAKARI_MONITORS_CONF_DIR
+       $MASAKARI_MONITORS_CONF_DIR/process_list.yaml
 
     sed -i 's/start nova-compute/start devstack@n-cpu/g' $MASAKARI_MONITORS_CONF_DIR/process_list.yaml
     sed -i 's/restart nova-compute/restart devstack@n-cpu/g' $MASAKARI_MONITORS_CONF_DIR/process_list.yaml
@@ -278,7 +269,7 @@ function install_masakaridashboard {
     $HORIZON_DIR/openstack_dashboard/local/enabled
     ln -fs $MASAKARI_DASHBOARD_DIR/masakaridashboard/local/local_settings.d/_50_masakari.py \
     $HORIZON_DIR/openstack_dashboard/local/local_settings.d
-    ln -fs $MASAKARI_DASHBOARD_DIR/masakaridashboard/conf/masakari_policy.json \
+    ln -fs $MASAKARI_DASHBOARD_DIR/masakaridashboard/conf/masakari_policy.yaml \
     $HORIZON_DIR/openstack_dashboard/conf
 }
 
@@ -286,7 +277,7 @@ function install_masakaridashboard {
 function uninstall_masakaridashboard {
     sudo rm -f  $DEST/horizon/openstack_dashboard/local/enabled/_50_masakaridashboard.py
     sudo rm -f  $DEST/horizon/openstack_dashboard/local/local_settings.d/_50_masakari.py
-    sudo rm -f  $DEST/horizon/openstack_dashboard/conf/masakari_policy.json
+    sudo rm -f  $DEST/horizon/openstack_dashboard/conf/masakari_policy.yaml
     restart_apache_server
 }
 
