@@ -62,7 +62,8 @@ class MasakariMigrationsCheckers(test_migrations.WalkVersionsMixin):
         old_level = migrate_log.level
         migrate_log.setLevel(logging.WARN)
         self.addCleanup(migrate_log.setLevel, old_level)
-
+        CONF.set_override('connection', str(self.migrate_engine.url),
+                          group='taskflow')
         self.useFixture(masakari_fixtures.Timeout(
             os.environ.get('OS_TEST_TIMEOUT', 0),
             self.TIMEOUT_SCALING_FACTOR))
@@ -210,6 +211,9 @@ class MasakariMigrationsCheckers(test_migrations.WalkVersionsMixin):
         self.assertColumnExists(engine, 'atomdetails', 'revert_results')
         self.assertColumnExists(engine, 'atomdetails', 'revert_failure')
 
+    def _check_007(self, engine, data):
+        self.assertColumnExists(engine, 'failover_segments', 'enabled')
+
 
 class TestMasakariMigrationsSQLite(MasakariMigrationsCheckers,
                                    test_base.DbTestCase):
