@@ -12,20 +12,36 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import datetime
+import iso8601
 from oslo_utils import timeutils
 from oslo_utils import uuidutils
 
 from masakari import objects
+from masakari.objects import segment as segment_obj
 from masakari.tests import uuidsentinel
 
 NOW = timeutils.utcnow().replace(microsecond=0)
 
 
+def _make_segment_obj(segment_dict):
+    return segment_obj.FailoverSegment(**segment_dict)
+
+
+FAILOVER_SEGMENT = {"name": "segment1", "id": "1",
+                    "service_type": "COMPUTE", "recovery_method": "auto",
+                    "uuid": uuidsentinel.fake_segment1,
+                    "description": "failover_segment for compute"}
+
+
+FAILOVER_SEGMENT = _make_segment_obj(FAILOVER_SEGMENT)
+
+
 class FakeNovaClient(object):
     class Server(object):
         def __init__(self, id=None, uuid=None, host=None, vm_state=None,
                      task_state=None, power_state=1, ha_enabled=None,
-                     locked=False):
+                     ha_enabled_key='HA_Enabled', locked=False):
             self.id = id
             self.uuid = uuid or uuidutils.generate_uuid()
             self.host = host
@@ -33,20 +49,24 @@ class FakeNovaClient(object):
             setattr(self, 'OS-EXT-STS:vm_state', vm_state)
             setattr(self, 'OS-EXT-STS:task_state', task_state)
             setattr(self, 'OS-EXT-STS:power_state', power_state)
-            self.metadata = {"HA_Enabled": ha_enabled}
+            self.metadata = {ha_enabled_key: ha_enabled}
             self.locked = locked
 
     class ServerManager(object):
         def __init__(self):
             self._servers = []
+            self.reset_state_calls = []
+            self.stop_calls = []
 
         def create(self, id, uuid=None, host=None, vm_state='active',
-                   task_state=None, power_state=1, ha_enabled=False):
+                   task_state=None, power_state=1, ha_enabled=False,
+                   ha_enabled_key='HA_Enabled'):
             server = FakeNovaClient.Server(id=id, uuid=uuid, host=host,
                                            vm_state=vm_state,
                                            task_state=task_state,
                                            power_state=power_state,
-                                           ha_enabled=ha_enabled)
+                                           ha_enabled=ha_enabled,
+                                           ha_enabled_key=ha_enabled_key)
             self._servers.append(server)
             return server
 
@@ -67,6 +87,8 @@ class FakeNovaClient(object):
             return matching
 
         def reset_state(self, uuid, status):
+            current_status = getattr(self.get(uuid), "OS-EXT-STS:vm_state")
+            self.reset_state_calls.append((uuid, current_status))
             server = self.get(uuid)
             setattr(server, 'OS-EXT-STS:vm_state', status)
 
@@ -76,12 +98,13 @@ class FakeNovaClient(object):
             server = self.get(uuid)
             setattr(server, 'OS-EXT-SRV-ATTR:hypervisor_hostname', host)
             # pretending that instance is evacuated successfully on given host
-            if getattr(server, "OS-EXT-STS:vm_state") == 'active':
+            if getattr(server, "OS-EXT-STS:vm_state") in ['active', 'error']:
                 setattr(server, 'OS-EXT-STS:vm_state', 'active')
             else:
                 setattr(server, 'OS-EXT-STS:vm_state', 'stopped')
 
         def stop(self, id):
+            self.stop_calls.append(id)
             server = self.get(id)
             setattr(server, 'OS-EXT-STS:vm_state', 'stopped')
 
@@ -136,8 +159,10 @@ class FakeNovaClient(object):
                                                          binary=binary,
                                                          status=status))
 
-        def disable(self, host_name, binary):
-            service = self.list(host=host_name, binary=binary)[0]
+        def disable(self, service_id):
+            for _service in self._services:
+                if _service.id == service_id:
+                    service = _service
             service.status = 'disabled'
 
         def list(self, host=None, binary=None):
@@ -163,21 +188,34 @@ def create_fake_notification(type="VM", id=1, payload=None,
         notification_uuid=notification_uuid)
 
 
-def create_fake_host(name='fake_host', id=1, reserved=False,
-                     on_maintenance=False, type='SSH',
-                     control_attributes='fake',
-                     uuid=uuidsentinel.fake_host,
-                     failover_segment_id=uuidsentinel.fake_segment):
-    return objects.Host(
-        name=name, id=id, reserved=reserved, on_maintenance=on_maintenance,
-        type=type, control_attributes=control_attributes, uuid=uuid,
-        failover_segment_id=failover_segment_id)
+def create_fake_host(**updates):
+    host = {
+        'name': 'fake_host', 'id': 1, 'reserved': False,
+        'on_maintenance': False, 'type': 'SSH',
+        'control_attributes': 'fake', 'uuid': uuidsentinel.fake_host,
+        'failover_segment': FAILOVER_SEGMENT,
+        'created_at': datetime.datetime(
+            2019, 8, 8, 0, 0, 0, tzinfo=iso8601.UTC),
+        'updated_at': None, 'deleted_at': None, 'deleted': False
+    }
+    if updates:
+        host.update(updates)
+    return objects.Host(**host)
 
 
 def create_fake_failover_segment(name='fake_segment', id=1, description=None,
                                  service_type='COMPUTE',
                                  recovery_method="auto",
-                                 uuid=uuidsentinel.fake_segment):
+                                 uuid=uuidsentinel.fake_segment,
+                                 enabled=True):
     return objects.FailoverSegment(
         name=name, id=id, description=description, service_type=service_type,
-        recovery_method=recovery_method, uuid=uuid)
+        recovery_method=recovery_method, uuid=uuid, enabled=enabled)
+
+
+def create_fake_notification_progress_details(
+        name, uuid, progress, state, progress_details):
+
+    return objects.NotificationProgressDetails(
+        name=name, uuid=uuid, progress=progress, state=state,
+        progress_details=progress_details)
